Imperium

codecov CI Pub.dev GitHub stars Last Commit Chat

A Framework for Flutter's Framework

Fluttery_Framework Allows for faster and easier development with better maintainability. It looks like Flutter because it works like Flutter. There's no 're-inventing of the wheel' here. If you know Flutter, you'll know Imperium.

It supplies the adaptive functions and features expected of a production-ready app:

  • An extended State class offering a built-in FutureBuilder or InheritedWidget.
  • A State Object Controller class for this State class
  • Extensive and essential error handling
  • Easy implementation of both the Material & Cupertino interface for one app i.e. One app with both an Android and iOS interface.
  • App-wide accessibility to your app's preferences using Shared Preferences
  • 27 device event-handlers
  • A loading screen option

Imperium Documentation

Fluttery Framework