StateXEventHandlers mixin StateX class State Object Controller Event handling

Supplies the event handling in all the StateXController and StateX objects.

dartdoc:

Implemented types
Mixin applications

Properties

debugPrintEvents bool
debugPrint the 'event handlers'
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
identifier String
A unique key is assigned to all State Controllers, State objects Used in large projects to separate objects into teams.
no setter
initAsyncCalled bool
Flag indicating initAsync() has been called
no setterinherited
logStateXError bool
Flag whether to log error details or not
getter/setter pairinherited
printEvents bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
deactivate() → void
The framework calls this method whenever it removes this StateX object from the tree.
detachedAppLifecycleState() → void
The Flutter engine is running but any interface is gone.
didChangeAccessibilityFeatures() → void
Called when the current accessibility features have been changed.
didChangeAppLifecycleState(AppLifecycleState state) → void
Called when the system puts the app in the background or returns the app to the foreground.
didChangeDependencies() → void
Called when immediately after initState. Otherwise called only if a dependency of an InheritedWidget.
didChangeLocales(List<Locale>? locales) → void
Called when the system tells the app that the user's locale has changed.
didChangeMetrics() → void
Called when the application's UI dimensions change. For example, when a phone is rotated.
didChangePlatformBrightness() → void
Brightness changed.
didChangeTextScaleFactor() → void
Called when the platform's text scale factor changes.
didChangeViewFocus(ViewFocusEvent event) → void
Called whenever the PlatformDispatcher receives a notification that the focus state on a view has changed.
didHaveMemoryPressure() → void
Called when the system is running low on memory.
didPop() → void
Called when this State is popped off a route.
override
didPopNext() → void
The top route has been popped off, and this route shows up.
override
didPopRoute() Future<bool>
Called when the system tells the app to pop the current route. For example, on Android, this is called when the user presses the back button.
didPush() → void
Called when this State is first added to as a Route observer?!
override
didPushNext() → void
New route has been pushed, and this State object's route is no longer current.
override
didPushRoute(String route) Future<bool>
Called when the host tells the app to push a new route onto the navigator.
didPushRouteInformation(RouteInformation routeInformation) Future<bool>
Called when the host tells the application to push a new RouteInformation and a restoration state onto the router.
didRequestAppExit() Future<AppExitResponse>
Called when a request is received from the system to exit the application. Exiting the application can proceed with AppExitResponse.exit; Cancel and do not exit the application with AppExitResponse.cancel;
didUpdateWidget(covariant StatefulWidget oldWidget) → void
Override this method to respond to when the StatefulWidget is recreated.
handleCancelBackGesture() → void
Called when a predictive back gesture is canceled, indicating that no navigation should occur.
handleCommitBackGesture() → void
Called when a predictive back gesture is finished successfully, indicating that the current route should be popped.
handleStartBackGesture(PredictiveBackEvent backEvent) bool
Called at the start of a predictive back gesture. If an observer returns true then that observer, and only that observer, will be notified of subsequent events in this same gesture (for example handleUpdateBackGestureProgress, etc.).
handleUpdateBackGestureProgress(PredictiveBackEvent backEvent) → void
Called when a predictive back gesture moves.
hiddenAppLifecycleState() → void
All views of an application are hidden, either because the application is about to be paused (on iOS and Android), or because it has been minimized or placed on a desktop that is no longer visible (on non-web desktop), or is running in a window or tab that is no longer visible (on the web).
inactiveAppLifecycleState() → void
The application is in an inactive state and is not receiving user input.
initAsync() Future<bool>
Initialize any 'time-consuming' operations at the beginning. Implement any asynchronous operations needed done at start up.
override
initAsyncState(covariant State<StatefulWidget> state) Future<bool>
Called with every StateX associated with this Controller Initialize any 'time-consuming' operations at the beginning. Implement any asynchronous operations needed done at start up.
override
initState() → void
The framework will call this method exactly once. Only when the StateX object is first created.
logErrorDetails(FlutterErrorDetails details, {bool? force}) → void
Logs 'every' error as the error count is reset.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAsyncError(FlutterErrorDetails details) → void
initAsync() has failed and a 'error' widget instead will be displayed. This takes in the snapshot.error details.
override
onError(FlutterErrorDetails details) → void
Offer an error handler
override
pausedAppLifecycleState() → void
The application is not currently visible to the user, not responding to user input, and running in the background.
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
resumedAppLifecycleState() → void
The application is visible and responding to user input.
runInitAsync() bool
Call initAsync() all the time if returns true. Conditional calls initAsync() creating a Future with every rebuild
toString() String
A string representation of this object.
inherited
updateShouldNotify(covariant InheritedWidget oldWidget) bool
Determine if its dependencies should be updated.

Operators

operator ==(Object other) bool
The equality operator.
inherited