handleStartBackGesture method
Called at the start of a predictive back gesture. If an observer returns true then that observer, and only that observer, will be notified of subsequent events in this same gesture (for example handleUpdateBackGestureProgress, etc.).
Observers are expected to return true if they were able to handle the notification, If all observers indicate they are not handling this back gesture by returning false, then a navigation pop will result when handleCommitBackGesture is called, as in a non-predictive system back gesture.
Currently, this is only used on Android devices that support the predictive back feature.
Implementation
bool handleStartBackGesture(PredictiveBackEvent backEvent) {
// Record the triggered event
assert(() {
if (_debugPrintEvents) {
debugPrint(
'$_consoleLeadingLine handleStartBackGesture() in $_consoleClassName');
}
return true;
}());
return false;
}