pausedAppLifecycleState method

void pausedAppLifecycleState()

The application is not currently visible to the user, not responding to user input, and running in the background.

Implementation

void pausedAppLifecycleState() {
  // Record the triggered event
  assert(() {
    if (_debugPrintEvents) {
      debugPrint(
          '$_consoleLeadingLine pausedAppLifecycleState() in $_consoleClassName');
    }
    return true;
  }());
}