activateState method

void activateState(
  1. covariant State<StatefulWidget> state
)
inherited

Called when this object is reinserted into the tree after having been removed via deactivate. Called when this object is reinserted into the tree after having been removed via deactivate.

Implementation

// @override
// void activate() {
//   // Optionally call super for debugPrint()
//   super.activate();
// }

/// Called when this object is reinserted into the tree after having been
/// removed via [deactivate].
void activateState(covariant State state) {
  // Optionally call super for debugPrint()
  assert(() {
    if (_debugPrintEvents) {
      debugPrint(
          '$_consoleLeadingLine activateState($state) in $_consoleClassName');
    }
    return true;
  }());
}