AppStateMixin class mixin StateX class State Object Controller

Supply access to the 'App' State object.

dartdoc:

Constructors

AppStateMixin()

Properties

appStateX → AppStateX<StatefulWidget>?
The App's State object
no setter
dataObject Object?
This is of type Object allowing you to propagate any class object you wish down the widget tree.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rootState → AppStateX<StatefulWidget>?
Returns the 'first' StateX object in the App
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited