rootState property
Returns the 'first' StateX object in the App
Implementation
// Important to prefix with the class name to 'share' this as a mixin.
@Deprecated('Use appStateX instead.')
AppStateX? get rootState => appStateX;
Returns the 'first' StateX object in the App
// Important to prefix with the class name to 'share' this as a mixin.
@Deprecated('Use appStateX instead.')
AppStateX? get rootState => appStateX;