initAsync method
Initialize any 'time-consuming' operations at the beginning. Implement any asynchronous operations needed done at start up.
Implementation
@mustCallSuper
Future<bool> initAsync() async {
_initAsyncCalled = true;
return true;
}
Initialize any 'time-consuming' operations at the beginning. Implement any asynchronous operations needed done at start up.
@mustCallSuper
Future<bool> initAsync() async {
_initAsyncCalled = true;
return true;
}