debugPrintGlobalKeyedWidgetLifecycle property
Log when widgets with global keys are deactivated and log when they are reactivated (retaken).
Implementation
bool? debugPrintGlobalKeyedWidgetLifecycle;
Log when widgets with global keys are deactivated and log when they are reactivated (retaken).
bool? debugPrintGlobalKeyedWidgetLifecycle;