debugRepaintTextRainbowEnabled property
Overlay a rotating set of colors when repainting text in debug mode.
Implementation
bool? debugRepaintTextRainbowEnabled;
Overlay a rotating set of colors when repainting text in debug mode.
bool? debugRepaintTextRainbowEnabled;