AppObjectImperium class Get started App object

This class is available throughout the app readily supplies static properties about the App.

dartdoc:

Mixed-in types

Constructors

AppObjectImperium()

Properties

appState AppStateX<StatefulWidget>?
The App State object.
getter/setter pair
asSmallScreen bool
Set whether the app is to use a 'small screen' or not.
no setterinherited
context BuildContext?
Retrieve the 'latest' context
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hotReload bool
Flag to set hot reload from now on.
getter/setter pair
inAndroid bool
no setterinherited
inDebugMode bool
Determines if running in an IDE or in production.
no setterinherited
inFlutterTest bool
Indicate if running under a 'Flutter Test' environment
no setterinherited
inFuchsia bool
no setterinherited
iniOS bool
no setterinherited
inLinux bool
no setterinherited
inMobile bool
no setterinherited
inSmallScreen bool
Return the bool value indicating if running in a small screen or not.
no setterinherited
inWeb bool
no setterinherited
inWidgetsFlutterBinding bool
Indicating app is running in the Flutter engine and not in the flutter_test framework with TestWidgetsFlutterBinding for example
no setterinherited
inWindows bool
no setterinherited
iOSThemeData CupertinoThemeData?
The app's current Cupertino theme.
getter/setter pairinherited
isInit bool
Determine if the App initialized successfully.
getter/setter pair
logStateXError bool
Flag whether to log error details or not
getter/setter pairinherited
mainWindow FlutterView
Flutter application's main window.
no setterinherited
platform TargetPlatform?
The running platform
no setterinherited
prefs SharedPreferencesAsync
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaffold ScaffoldState?
The Scaffold object for this App's View.
no setterinherited
screenHeight double
The 'Logical' height of the screen
no setterinherited
screenPhysicalHeight double
The Physical height of the screen
no setterinherited
screenPhysicalWidth double
The Physical width of the screen
no setterinherited
screenSize Size
Current Screen Size
no setterinherited
screenWidth double
The 'logical' width of the screen
no setterinherited
standAloneApp bool?
Determine if this app is running alone
getter/setter pair
themeData ThemeData?
The App's current Material theme.
getter/setter pairinherited
useCupertino bool
Indicates if the App is running the Cupertino interface theme.
no setterinherited
useMaterial bool
Indicates if the App is running the Material interface theme.
no setterinherited

Methods

catchError(Object? ex, {StackTrace? stack, String? library, DiagnosticsNode? context, IterableFilter<String>? stackFilter, InformationCollector? informationCollector, bool? silent}) → void
Catch and explicitly handle the error.
inherited
dependOnInheritedWidget(BuildContext? context) → void
Link a widget to a InheritedWidget in the root State object.
inherited
dispose() → void
Dispose the App properties.
override
getPlatform(BuildContext context) TargetPlatform
Determine the running platform
inherited
logErrorDetails(FlutterErrorDetails details, {bool? force}) → void
Log an Error
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyClients() → void
Rebuild dependencies to the root State object's InheritedWidget
inherited
onError(FlutterErrorDetails details) → void
Offer an error handler
inherited
setState(VoidCallback fn) → void
Refresh the root State object with the passed function.
inherited
setThemeData({ColorSwatch<int?>? swatch}) Color?
Set the app's general color theme supplying a Color value.
inherited
snackBar({Key? key, Widget? content, String? message, Color? backgroundColor, double? elevation, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, double? width, ShapeBorder? shape, SnackBarBehavior? behavior, SnackBarAction? action, Duration? duration, Animation<double>? animation, VoidCallback? onVisible, DismissDirection? dismissDirection, Clip? clipBehavior, int? durationMillis, int? animationDurationMillis}) → void
Display the SnackBar
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

logError bool
Flag whether to log the next error
getter/setter pair