AppStateX<T extends StatefulWidget> class
Get started
StateX class
AppState class
Error handling
The View for the app. The 'look and feel' for the whole app.
dartdoc:
- Inheritance
-
- Object
- State<
StatefulWidget> - StateX<
T> - AppStateX<
T> - AppStateX
- Implemented types
Constructors
-
AppStateX({Key? key, Widget? home, AppStateXController? controller, List<
StateXController> ? controllers, Object? object, bool? notifyClientsInBuild, bool? printEvents, MaterialApp? materialApp, CupertinoApp? cupertinoApp, RouteInformationProvider? routeInformationProvider, RouteInformationParser<Object> ? routeInformationParser, RouterDelegate<Object> ? routerDelegate, bool? useRouterConfig, RouterConfig<Object> ? routerConfig, BackButtonDispatcher? backButtonDispatcher, GlobalKey<ScaffoldMessengerState> ? scaffoldMessengerKey, Map<String, WidgetBuilder> ? routes, String? initialRoute, Route? generateRoute, Route? unknownRoute, TransitionBuilder? builder, String? title, String onGenerateTitle(BuildContext context)?, Color? color, ThemeData? theme, CupertinoThemeData? iOSTheme, ThemeData? darkTheme, ThemeData? highContrastTheme, ThemeData? highContrastDarkTheme, ThemeMode? themeMode, Duration? themeAnimationDuration, Curve? themeAnimationCurve, Locale? locale, Iterable<LocalizationsDelegate> ? localizationsDelegates, LocaleListResolutionCallback? localeListResolutionCallback, LocaleResolutionCallback? localeResolutionCallback, List<Locale> ? supportedLocales, bool? useMaterial, bool? useCupertino, bool? switchUI, bool? inSwitchUI()?, bool? debugShowMaterialGrid, bool? showPerformanceOverlay, bool? checkerboardRasterCacheImages, bool? checkerboardOffscreenLayers, bool? showSemanticsDebugger, bool? debugShowCheckedModeBanner, bool? debugShowWidgetInspector, bool? debugPaintSizeEnabled, bool? debugPaintBaselinesEnabled, bool? debugPaintPointersEnabled, bool? debugPaintLayerBordersEnabled, bool? debugRepaintRainbowEnabled, bool? debugRepaintTextRainbowEnabled, bool? debugPrintRebuildDirtyWidgets, RebuildDirtyWidgetCallback? debugOnRebuildDirtyWidget, bool? debugPrintBuildScope, bool? debugPrintScheduleBuildForStacks, bool? debugPrintGlobalKeyedWidgetLifecycle, bool? debugProfileBuildsEnabled, bool? debugProfileBuildsEnabledUserWidgets, bool? debugEnhanceBuildTimelineArguments, bool? debugHighlightDeprecatedWidgets, Map<LogicalKeySet, Intent> ? shortcuts, Map<Type, Action< ? actions, String? restorationScopeId, ScrollBehavior? scrollBehavior, AnimationStyle? themeAnimationStyle, FlutterExceptionHandler? errorHandler, ErrorWidgetBuilder? errorScreen, ReportErrorHandler? errorReport, void inErrorHandler(FlutterErrorDetails details)?, ErrorWidgetBuilder? inErrorScreen, Future<Intent> >void> inErrorReport(Object exception, StackTrace stack)?, bool? presentError, void inInitState()?, Future<bool> inInitAsync()?, Future<bool> inCatchAsyncError(Object error)?, void inAsyncError(Object error)?, Widget? inHome()?, RouteInformationProvider inRouteInformationProvider()?, RouteInformationParser<Object> inRouteInformationParser()?, RouterDelegate<Object> inRouterDelegate()?, RouterConfig<Object> ? inRouterConfig()?, BackButtonDispatcher inBackButtonDispatcher()?, Map<String, WidgetBuilder> inRoutes()?, String inInitialRoute()?, RouteFactory? inGenerateRoute, RouteFactory? inUnknownRoute, GlobalKey<ScaffoldMessengerState> ? inScaffoldMessengerKey()?, bool inUpdateShouldNotify(InheritedWidget oldWidget)?, TransitionBuilder inTransBuilder()?, String inTitle()?, GenerateAppTitle? inGenerateTitle, ThemeData? inTheme([BuildContext? context])?, CupertinoThemeData? iniOSTheme([BuildContext? context])?, ThemeData? inDarkTheme([BuildContext? context])?, ThemeData? inHighContrastTheme([BuildContext? context])?, ThemeData? inHighContrastDarkTheme([BuildContext? context])?, ThemeMode? inThemeMode()?, Duration? inThemeAnimationDuration()?, Curve? inThemeAnimationCurve()?, Color? inColor()?, Locale? inLocale()?, Iterable<LocalizationsDelegate> inLocalizationsDelegates()?, LocaleListResolutionCallback? inLocaleListResolutionCallback, LocaleResolutionCallback? inLocaleResolutionCallback, List<Locale> ? inSupportedLocales()?, bool? inDebugShowMaterialGrid()?, bool? inShowPerformanceOverlay()?, bool? inCheckerboardRasterCacheImages()?, bool? inCheckerboardOffscreenLayers()?, bool? inShowSemanticsDebugger()?, bool? inDebugShowCheckedModeBanner()?, BooleanFunctionIndicatorCallback? inDebugPaintSizeEnabled, BooleanFunctionIndicatorCallback? inDebugPaintBaselinesEnabled, BooleanFunctionIndicatorCallback? inDebugPaintPointersEnabled, BooleanFunctionIndicatorCallback? inDebugPaintLayerBordersEnabled, BooleanFunctionIndicatorCallback? inDebugRepaintRainbowEnabled, BooleanFunctionIndicatorCallback? inDebugRepaintTextRainbowEnabled, BooleanFunctionIndicatorCallback? inDebugPrintRebuildDirtyWidgets, RebuildDirtyWidgetCallback? inDebugOnRebuildDirtyWidget, BooleanFunctionIndicatorCallback? inDebugPrintBuildScope, BooleanFunctionIndicatorCallback? inDebugPrintScheduleBuildForStacks, BooleanFunctionIndicatorCallback? inDebugPrintGlobalKeyedWidgetLifecycle, BooleanFunctionIndicatorCallback? inDebugProfileBuildsEnabled, BooleanFunctionIndicatorCallback? inDebugProfileBuildsEnabledUserWidgets, BooleanFunctionIndicatorCallback? inDebugEnhanceBuildTimelineArguments, BooleanFunctionIndicatorCallback? inDebugHighlightDeprecatedWidgets, Map<LogicalKeySet, Intent> ? inShortcuts()?, Map<Type, Action< ? inActions()?, String? inRestorationScopeId()?, ScrollBehavior? inScrollBehavior()?, AnimationStyle? inThemeAnimationStyle()?})Intent> > - Provide a huge array of options and features to the 'App State object.'
Properties
- appCon → StateXController?
-
Returns 'the first' StateXController associated with this StateX object.
Returns null if empty.
no setterinherited
- appInApp ↔ bool
-
This App is within another App
getter/setter pair
-
appStateX
↔ AppStateX<
StatefulWidget> ? -
Reference the App State object
getter/setter pairinherited
- builderOverridden → bool
-
A flag. Note if builder() function was overridden or not.
no setterinherited
- buildFOverridden → bool
-
A flag. If the buildF() function was overridden or not.
no setterinherited
- buildOverridden → bool
-
A flag. If the build() function was overridden or not.
no setterinherited
- caughtAsyncError → bool
-
A flag noting an Async error was caught or not
no setterinherited
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- controller → StateXController?
-
Provide the 'main' controller to this State object.
If _controller == null, get the 'first assigned' controller if any.
no setterinherited
-
controllerList
→ List<
StateXController> -
Supply a public list of all the Controllers.
no setterinherited
- cupertinoApp ↔ CupertinoApp?
-
getter/setter pairinherited
- dataObject ↔ Object?
-
This is of type Object allowing you
to propagate any class object you wish down the widget tree.
getter/setter pairinherited
- deactivated → bool
-
State object's deactivated() was called.
no setterinherited
- debugEnhanceBuildTimelineArguments ↔ bool?
-
Adds debugging information to 'Timeline' events related to Widget builds.
getter/setter pairinherited
- debugHighlightDeprecatedWidgets ↔ bool?
-
Show banners for deprecated widgets.
getter/setter pairinherited
- debugOnRebuildDirtyWidget ↔ void Function(Element e, bool builtOnce)?
-
Callback invoked for every dirty widget built each frame.
getter/setter pairinherited
- debugPaintBaselinesEnabled ↔ bool?
-
Causes each RenderBox to paint a line at each of its baselines.
getter/setter pairinherited
- debugPaintLayerBordersEnabled ↔ bool?
-
Causes each Layer to paint a box around its bounds.
getter/setter pairinherited
- debugPaintPointersEnabled ↔ bool?
-
Causes objects like 'RenderPointerListener' to flash when tapped.
getter/setter pairinherited
- debugPaintSizeEnabled ↔ bool?
-
Highlights UI while debugging.
getter/setter pairinherited
- debugPrintBuildScope ↔ bool?
-
Log all calls to BuildOwner.buildScope.
getter/setter pairinherited
- debugPrintEvents ↔ bool
-
debugPrint the 'event handlers'
getter/setter pairinherited
- debugPrintGlobalKeyedWidgetLifecycle ↔ bool?
-
Log when widgets with global keys are deactivated and log when they are reactivated (retaken).
getter/setter pairinherited
- debugPrintRebuildDirtyWidgets ↔ bool?
-
Log the dirty widgets that are built each frame.
getter/setter pairinherited
- debugPrintScheduleBuildForStacks ↔ bool?
-
Log the call stacks that mark widgets as needing to be rebuilt.
getter/setter pairinherited
- debugProfileBuildsEnabled ↔ bool?
-
Adds 'Timeline' events for every Widget built.
getter/setter pairinherited
- debugProfileBuildsEnabledUserWidgets ↔ bool?
-
Adds 'Timeline' events for every user-created Widget built.
getter/setter pairinherited
- debugRepaintRainbowEnabled ↔ bool?
-
Overlay a rotating set of colors when repainting layers in debug mode.
getter/setter pairinherited
- debugRepaintTextRainbowEnabled ↔ bool?
-
Overlay a rotating set of colors when repainting text in debug mode.
getter/setter pairinherited
- detachedAppLifecycle → bool
-
State object was in 'paused' state
no setterinherited
- disposed → bool
-
Flag indicating this State object is disposed.
Will be garbage collected.
property, mounted, is then set to false.
no setterinherited
- errorHandler ↔ FlutterExceptionHandler?
-
getter/setter pairinherited
- errorReport ↔ ReportErrorHandler?
-
getter/setter pairinherited
- errorScreen ↔ ErrorWidgetBuilder?
-
getter/setter pairinherited
- errorStateName → String
-
The name of the State object experiencing an error
no setterinherited
- firstBuild → bool
-
State object's first build or will be its first build
no setterinherited
- firstCon → StateXController?
-
Returns 'the first' StateXController associated with this StateX object.
Returns null if empty.
no setterinherited
-
firstState
→ StateX<
StatefulWidget> ? -
Return the first State object
no setterinherited
- hadSystemEvent → bool
-
State object experienced a system event
no setterinherited
- hasErrorInErrorHandler → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
All views of an application are hidden, either because the application is
about to be paused (on iOS and Android), or because it has been minimized
or placed on a desktop that is no longer visible (on non-web desktop), or
is running in a window or tab that is no longer visible (on the web).
State object was in a 'hidden' state
no setterinherited
- identifier → String
-
The unique identifier for this State object.
no setterinherited
- ignoreErrorInTesting ↔ bool
-
A flag testing the Error routine INSIDE the testing
It's set and reset ONLY when testing.
Allows a one-time even to ignore an error during testing.
getter/setter pairinherited
-
inActions
→ Map<
Type, Action< ? Function()?Intent> > -
Returns Map of 'Intent Actions' if any.
finalinherited
- inactiveAppLifecycle → bool
-
State object was in 'inactive' state
no setterinherited
- inAsyncError → void Function(Object error)?
-
Returns the App's 'Async Error Handler' if any.
finalinherited
- inBackButtonDispatcher → BackButtonDispatcher Function()?
-
Returns the 'Back Button' routine if any.
finalinherited
-
inCatchAsyncError
→ Future<
bool> Function(Object error)? -
Catch initAsync() error
finalinherited
- inCheckerboardOffscreenLayers → bool? Function()?
-
Returns 'Off Screen Layers Checkerboard' boolean indicator if any.
finalinherited
- inCheckerboardRasterCacheImages → bool? Function()?
-
Returns 'Raster Cache Checkerboard' boolean indicator if any.
finalinherited
- inColor → Color? Function()?
-
Returns the App's Color if any.
finalinherited
- inDarkTheme → ThemeData? Function([BuildContext? context])?
-
Returns the App's 'Dark Theme' ThemeData if any.
finalinherited
- inDebugEnhanceBuildTimelineArguments ↔ BooleanFunctionIndicatorCallback?
-
Returns 'debugging information to 'Timeline' events' boolean indicator.
getter/setter pairinherited
- inDebugHighlightDeprecatedWidgets ↔ BooleanFunctionIndicatorCallback?
-
Returns 'Show banners for deprecated widgets' boolean indicator.
getter/setter pairinherited
- inDebugMode → bool
-
Determines if running in an IDE or in production.
Returns true if the App is under in the Debugger and not production.
no setterinherited
- inDebugOnRebuildDirtyWidget ↔ RebuildDirtyWidgetCallback?
-
Callback invoked for every dirty widget built each frame.
getter/setter pairinherited
- inDebugPaintBaselinesEnabled ↔ BooleanFunctionIndicatorCallback?
-
Returns 'to paint a line at each of its baselines' boolean indicator.
getter/setter pairinherited
- inDebugPaintLayerBordersEnabled ↔ BooleanFunctionIndicatorCallback?
-
Returns 'to paint a box around its bounds' boolean indicator.
getter/setter pairinherited
- inDebugPaintPointersEnabled ↔ BooleanFunctionIndicatorCallback?
-
Returns 'to flash when tapped' boolean indicator.
getter/setter pairinherited
- inDebugPaintSizeEnabled ↔ BooleanFunctionIndicatorCallback?
-
Returns 'Highlights UI while debugging' boolean indicator.
getter/setter pairinherited
- inDebugPrintBuildScope ↔ BooleanFunctionIndicatorCallback?
-
Returns 'Highlights UI while debugging' boolean indicator.
getter/setter pairinherited
- inDebugPrintGlobalKeyedWidgetLifecycle ↔ BooleanFunctionIndicatorCallback?
-
Returns 'when widgets with global keys are deactivate' boolean indicator.
getter/setter pairinherited
- inDebugPrintRebuildDirtyWidgets ↔ BooleanFunctionIndicatorCallback?
-
Returns 'Log the dirty widgets that are built each frame' boolean indicator.
getter/setter pairinherited
- inDebugPrintScheduleBuildForStacks ↔ BooleanFunctionIndicatorCallback?
-
Returns 'mark widgets needed to be rebuilt' boolean indicator.
getter/setter pairinherited
- inDebugProfileBuildsEnabled ↔ BooleanFunctionIndicatorCallback?
-
Returns 'Adds 'Timeline' events' boolean indicator.
getter/setter pairinherited
- inDebugProfileBuildsEnabledUserWidgets ↔ BooleanFunctionIndicatorCallback?
-
Returns 'Highlights UI while debugging' boolean indicator.
getter/setter pairinherited
- inDebugRepaintRainbowEnabled ↔ BooleanFunctionIndicatorCallback?
-
Returns 'Overlay a rotating set of colors' boolean indicator.
getter/setter pairinherited
- inDebugRepaintTextRainbowEnabled ↔ BooleanFunctionIndicatorCallback?
-
Returns 'Overlay a rotating set of colors' boolean indicator.
getter/setter pairinherited
- inDebugShowCheckedModeBanner → bool? Function()?
-
Returns 'Show Debug Banner' boolean indicator if any.
finalinherited
- inDebugShowMaterialGrid → bool? Function()?
-
Returns 'Show Material Grid' boolean indicator if any.
finalinherited
- inDebugShowWidgetInspector → bool? Function()?
-
Returns 'Show Debug Widget Inspector' boolean indicator if any.
finalinherited
- inErrorHandler → void Function(FlutterErrorDetails details)?
-
finalinherited
-
inErrorReport
→ Future<
void> Function(Object exception, StackTrace stack)? -
finalinherited
- inErrorRoutine → bool
-
A flag indicating we're running in the error routine.
Set to avoid infinite loop if in errors in the error routine.
no setterinherited
- inErrorScreen → ErrorWidgetBuilder?
-
finalinherited
- inFlutterTest → bool
-
Indicate if running under a 'Flutter Test' environment
no setterinherited
- inGenerateRoute → RouteFactory?
-
Return a Route from the 'inline' routine.
finalinherited
- inGenerateTitle → GenerateAppTitle?
-
Returns the 'Generate Title' routine if any.
finalinherited
- inHighContrastDarkTheme → ThemeData? Function([BuildContext? context])?
-
Returns the App's 'High Contrast Dark Theme' ThemeData if any.
finalinherited
- inHighContrastTheme → ThemeData? Function([BuildContext? context])?
-
Returns the App's 'High Contrast Theme' ThemeData if any.
finalinherited
- inHome → Widget? Function()?
-
Returns the home screen if any.
finalinherited
-
inInitAsync
→ Future<
bool> Function()? -
Perform asynchronous operations
finalinherited
- inInitialRoute → String Function()?
-
Returns the initial Route if any.
finalinherited
- inInitState → void Function()?
-
Perform synchronous initialization
finalinherited
- iniOSTheme → CupertinoThemeData? Function([BuildContext? context])?
-
Returns the App's CupertinoThemeData if any.
finalinherited
- initAsyncCalled → bool
-
Flag indicating initAsync() has been called
no setterinherited
- inLocale → Locale? Function()?
-
Returns current Locale if any.
finalinherited
- inLocaleListResolutionCallback → LocaleListResolutionCallback?
-
Returns 'Locale Resolutions' routine if any.
finalinherited
- inLocaleResolutionCallback → LocaleResolutionCallback?
-
Returns 'Local Resolution' routine if any.
finalinherited
-
inLocalizationsDelegates
→ Iterable<
LocalizationsDelegate> Function()? -
Returns the 'Localization Delegates' if any.
finalinherited
-
Returns a List of Navigation Observers if any.
finalinherited
- inRestorationScopeId → String? Function()?
-
Returns the 'Restore Scope Id' routine if any.
finalinherited
-
inRouteInformationParser
→ RouteInformationParser<
Object> Function()? -
Returns the Route Parser if any.
finalinherited
- inRouteInformationProvider → RouteInformationProvider Function()?
-
Returns the Route Provider if any.
finalinherited
-
inRouterConfig
→ RouterConfig<
Object> ? Function()? -
Returns the Route Config if any.
finalinherited
-
inRouterDelegate
→ RouterDelegate<
Object> Function()? -
Returns the Route Delegate if any.
finalinherited
-
inRoutes
→ Map<
String, WidgetBuilder> Function()? -
Returns a Map of Routes if any.
finalinherited
-
inScaffoldMessengerKey
→ GlobalKey<
ScaffoldMessengerState> ? Function()? -
finalinherited
- inScrollBehavior → ScrollBehavior? Function()?
-
Returns the App's ScrollBehavior if any.
finalinherited
-
inShortcuts
→ Map<
LogicalKeySet, Intent> ? Function()? -
Returns Map of 'LogicalKeySets' if any.
finalinherited
- inShowPerformanceOverlay → bool? Function()?
-
Returns 'Show Performance Overlay' boolean indicator if any.
finalinherited
- inShowSemanticsDebugger → bool? Function()?
-
Returns 'Show Semantics' boolean indicator if any.
finalinherited
-
inSupportedLocales
→ List<
Locale> ? Function()? -
Returns the Locale Iteration if any.
finalinherited
- inSwitchUI → bool? Function()?
-
If the app is to switch from the 'default' interface
final
- inTheme → ThemeData? Function([BuildContext? context])?
-
Returns the App's ThemeData if any.
finalinherited
- inThemeAnimationCurve → Curve? Function()?
-
The curve to apply when animating theme changes.
finalinherited
- inThemeAnimationDuration → Duration? Function()?
-
The duration of animated theme changes.
finalinherited
- inThemeAnimationStyle → AnimationStyle? Function()?
-
Used to override the theme animation curve and duration.
finalinherited
- inThemeMode → ThemeMode? Function()?
-
Returns the App's ThemeMode if any.
finalinherited
- inTitle → String Function()?
-
Returns the App's title if any.
finalinherited
- inTransBuilder → TransitionBuilder Function()?
-
Returns the 'Transition Builder' if any.
finalinherited
- inUnknownRoute → RouteFactory?
-
From an 'inline' routine, return the 'unknown' route
finalinherited
- inUpdateShouldNotify → bool Function(InheritedWidget oldWidget)?
-
Should update the built-in InheritedWidget's dependencies
finalinherited
- inWidgetsFlutterBinding → bool
-
Indicating app is running in the Flutter engine and not in
the
flutter_testframework with TestWidgetsFlutterBinding for exampleno setterinherited - isLastState → bool
-
This is the 'latest' State being viewed by the App.
no setterinherited
- key → Key
-
The 'App State Objects' Key
no setter
- lastCon → StateXController?
-
Returns 'the last' StateXController associated with this StateX object.
Returns null if empty.
no setterinherited
- lastContext → BuildContext?
-
Returns the 'latest' context in the App.
no setterinherited
- lastFlutterErrorDetails → FlutterErrorDetails?
-
Supply the last Flutter Error Details if any.
no setterinherited
- lastFlutterErrorMessage → String
-
Return the message of th 'last' Flutter Error if any.
no setterinherited
-
lastState
→ StateX<
StatefulWidget> ? -
Return the 'latest' State object
no setterinherited
- locale ↔ Locale?
-
getter/setter pairinherited
- logStateXError ↔ bool
-
Flag whether to log error details or not
getter/setter pairinherited
- materialApp ↔ MaterialApp?
-
The MaterialApp and CupertinoApp if provided.
getter/setter pairinherited
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
-
Use this to navigate throughout the your app
no setterinherited
-
The Navigator State Key
no setterinherited
-
no setterinherited
-
parentState
↔ State<
StatefulWidget> ? -
Reference the 'parent' State object
getter/setter pair
- pausedAppLifecycle → bool
-
The application is not currently visible to the user, not responding to
user input, and running in the background.
(Called only in iOS, Android)
State object was in 'paused' state
no setterinherited
- presentError ↔ bool?
-
getter/setter pairinherited
- printEvents → bool
-
no setterinherited
- recErrorException → Object?
-
The Error or Exception
no setterinherited
- recErrorMsg → String
-
Simply display the exception.
no setterinherited
- recHasError → bool
-
Indicate if an exception had occurred.
no setterinherited
- recStackTrace → StackTrace?
-
The StackTrace
no setterinherited
- resumedAppLifecycle → bool
-
State object was in 'resumed' state
no setterinherited
- rootCon → StateXController?
-
Returns 'the first' StateXController associated with this StateX object.
Returns null if empty.
no setterinherited
-
rootState
→ AppStateX<
StatefulWidget> ? -
Returns the 'first' StateX object in the App
no setterinherited
- routesGenerated → bool
-
Flag telling you if the routes were generated or not
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scaffoldMessengerKey
→ GlobalKey<
ScaffoldMessengerState> ? -
You may need this key to display an SnackBar
no setterinherited
-
snapshot
→ AsyncSnapshot<
bool> ? -
Supply the AsyncSnapshot
no setterinherited
-
supportedLocales
→ List<
Locale> -
no setterinherited
- switchUI → bool
-
Allow the app to change the theme
Allow the app directly change the Locale
Allow the app to directly change the UI design
Use Cupertino UI in Android and vice versa.
no setter
- title → String
-
no setterinherited
- useCupertino → bool
-
Explicitly use the Cupertino theme
no setter
- useInherited → bool
-
A flag determining whether the built-in InheritedWidget is used or not.
no setterinherited
- useMaterial → bool
-
Explicitly use the Material theme
no setter
- usingCupertino → bool
-
Is the CupertinoApp being used?
no setterinherited
- widget → T
-
You need to be able access the widget.
no setteroverride
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
add(
StateXController? con) → String -
Collect a 'StateXController'
Returns the StateXController's unique identifier.
inherited
-
addAll(
List< StateXController> ? list) → List<String> -
Add a list of 'Controllers' to be associated with this StatX object.
inherited
-
addList(
List< StateXController> ? list) → List<String> -
Collect a list of 'Controllers'.
inherited
-
Add a Navigation listener.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
buildApp(
AppStateX< StatefulWidget> ? appState) → Widget? - Supply the App widget if you wish.
-
builder(
BuildContext context) → Widget -
Use this function instead of the build() function
override
-
buildF(
BuildContext context) → Widget -
Implement this function instead of the build() function
to utilize a built-in FutureBuilder Widget.
inherited
-
buildWrap(
Widget child) → Widget - Optional build function Wraps the AppStateX widget.
-
catchAsyncError(
Object error) → Future< bool> -
Catch it if the initAsync() throws an error
The FutureBuilder will fail, but you can examine the error
inherited
-
catchError(
Exception? ex, {StackTrace? stack, String? library, DiagnosticsNode? context, IterableFilter< String> ? stackFilter, InformationCollector? informationCollector, bool? silent}) → void -
Catch and explicitly handle the error.
inherited
-
changeUI(
String? ui) → bool - Explicitly change to a particular interface.
-
contains(
StateXController con) → bool -
Returns true if found.
inherited
-
containsId(
String? id) → bool -
Returns true if the specified 'StateXController' is associated with this StateX object.
inherited
-
containsType<
T> () → bool -
Returns true if found
inherited
-
controllerById(
String? id) → StateXController? -
Retrieve a StateXController by its a unique String identifier.
inherited
-
controllerByType<
U extends StateXController> () → U? -
Retrieve a StateXController by type.
inherited
-
deactivate(
) → void -
The framework calls this method whenever it removes this
StateXobject from the tree. In many cases, it is about to be 'disposed of'.inherited -
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
dependOnInheritedWidget(
BuildContext? context) → bool -
Set the specified widget (through its context) as a dependent of the InheritedWidget
inherited
-
detachedAppLifecycleState(
) → void -
Either be in the progress of attaching when the engine is first initializing
or after the view being destroyed due to a Navigator pop.
The application is still hosted on a flutter engine but is detached from any host views.
Its firing will depending on the hosting operating system:
https://github.com/flutter/flutter/issues/124945#issuecomment-1514159238
inherited
-
didChangeAccessibilityFeatures(
) → void -
Called when the system changes the set of currently active accessibility features.
inherited
-
didChangeAppLifecycleState(
AppLifecycleState lifecycleState) → void -
Called when the system puts the app in the background or returns
the app to the foreground.
AppLifecycleState.inactive:
AppLifecycleState.hidden:
AppLifecycleState.paused:
AppLifecycleState.resumed:
AppLifecycleState.detached:
inherited
-
didChangeDependencies(
) → void -
This method is also called immediately after initState.
Otherwise called only if this State object's Widget
is a dependency of InheritedWidget.
When a InheritedWidget's build() function is called
the dependent widget's build() function is also called but not before
their didChangeDependencies() function. Subclasses rarely use this method.
inherited
-
didChangeLocales(
List< Locale> ? locales) → void -
Called when the system tells the app that the user's locale has
changed. For example, if the user changes the system language
settings.
inherited
-
didChangeMetrics(
) → void -
Called when the application's dimensions change. For example,
when a phone is rotated.
inherited
-
didChangePlatformBrightness(
) → void -
Called when the platform brightness changes.
inherited
-
didChangeTextScaleFactor(
) → void -
Called when the platform's text scale factor changes.
inherited
-
didChangeViewFocus(
ViewFocusEvent event) → void -
Called whenever the PlatformDispatcher receives a notification that the
focus state on a view has changed.
inherited
-
didHaveMemoryPressure(
) → void -
Called when the system is running low on memory.
inherited
-
didPop(
) → void -
Called when this route has been popped off.
inherited
-
didPopNext(
) → void -
The top route has been popped off, and this route shows up.
inherited
-
didPopRoute(
) → Future< bool> -
Called when the system tells the app to pop the current route, such as
after a system back button press or back gesture.
inherited
-
didPush(
) → void -
Called when this route has been pushed.
inherited
-
didPushNext(
) → void -
New route has been pushed, and this route is no longer visible.
inherited
-
didPushRoute(
String route) → Future< bool> -
Called when the host tells the app to push a new route onto the
navigator.
inherited
-
didPushRouteInformation(
RouteInformation routeInformation) → Future< bool> -
Called when the host tells the application to push a new
RouteInformation and a restoration state onto the router.
inherited
-
didRequestAppExit(
) → Future< AppExitResponse> -
Called when a request is received from the system to exit the application.
inherited
-
didUpdateController(
{StateXController? oldCon, StateXController? newCon}) → bool -
Update the 'first' controller if necessary
Place in the
didUpdateWidgetfunction in the special case the StatefulWidget supplies the controller: e.g. didUpdateController(oldWidget.controller, widget.controller);inherited -
didUpdateWidget(
covariant T oldWidget) → void -
Override this method to respond when its StatefulWidget is re-created.
The framework always calls build after calling
didUpdateWidget, which means any calls tosetStateindidUpdateWidgetare redundant.inherited -
dispose(
) → void - Clean up resources before the app is finally terminated.
-
forEach(
void func(StateXController con), {bool? reversed}) → bool -
To externally 'process' through the controllers.
Invokes
funcon each StateXController possessed by this StateX object. With an option to process in reversed chronological orderinherited -
forEachState(
void func(StateX< StatefulWidget> state), {bool? reversed, StateX<StatefulWidget> ? remove}) → bool -
To externally 'process' through the State objects.
Invokes
funcon each StateX possessed by this StateX object. With an option to process in reversed chronological orderinherited -
handleCancelBackGesture(
) → void -
Called when a predictive back gesture is canceled, indicating that no
navigation should occur.
inherited
-
handleCommitBackGesture(
) → void -
Called when a predictive back gesture is finished successfully, indicating
that the current route should be popped.
inherited
-
handleStartBackGesture(
PredictiveBackEvent backEvent) → bool -
Called at the start of a predictive back gesture.
If an observer returns true then that observer, and only that observer,
will be notified of subsequent events in
this same gesture (for example
handleUpdateBackGestureProgress, etc.).inherited -
handleStatusBarTap(
) → void -
Called when the user taps the status bar on iOS, to scroll a scroll
view to the top.
inherited
-
handleUpdateBackGestureProgress(
PredictiveBackEvent backEvent) → void -
Called when a predictive back gesture moves.
inherited
-
All views of an application are hidden, either because the application is
about to be paused (on iOS and Android), or because it has been minimized
or placed on a desktop that is no longer visible (on non-web desktop), or
is running in a window or tab that is no longer visible (on the web).
inherited
-
hotReload(
) → void - Reload the whole App
-
inactiveAppLifecycleState(
) → void -
Apps in this state should assume that they may be pausedAppLifecycleState at any time.
inherited
-
initAsync(
) → Future< bool> -
Used to complete asynchronous operations
override
-
initAsyncState(
covariant State< StatefulWidget> state) → Future<bool> -
Called with every
StateXassociated with this Controller Initialize any 'time-consuming' operations at the beginning. Implement any asynchronous operations needed done at start up.inherited -
initState(
) → void -
The traditional initState for the App's first State object
override
-
lastFlutterError(
[FlutterErrorDetails? details]) → FlutterErrorDetails? -
Record and return details of the 'last' handled error
Not, simply retrieving the last error will 'clear' the storage.
inherited
-
listControllers(
List< String?> ? keys) → List<StateXController?> -
Returns the list of 'Controllers' but you must know their keys.
inherited
-
listStates(
List< String> keys) → List<StateX< StatefulWidget> > -
Returns a List of StateX objects using unique String identifiers.
inherited
-
logErrorDetails(
FlutterErrorDetails details, {bool? force}) → void -
Logs 'every' error as the error count is reset.
force - Forces the log despite flag setting of logStateXError
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyClients(
) → bool -
Notify the InheritedWidget's dependencies
inherited
-
ofState<
T extends StateX< (StatefulWidget> >) → T? -
Consistent with the equivalent in the StateXController class
inherited
-
onActions(
) → Map< Type, Action< ?Intent> > -
Returns Map of 'Intent Actions' if any.
inherited
-
onAsyncError(
FlutterErrorDetails details) → void -
initAsync() has failed and a 'error' widget instead will be displayed.
This takes in the snapshot.error details.
inherited
-
onBackButtonDispatcher(
) → BackButtonDispatcher? -
Returns the 'Back Button' routine if any.
inherited
-
onBuilder(
) → TransitionBuilder? -
Returns the 'Transition Builder' if any.
inherited
-
onCatchAsyncError(
Object error) → Future< bool> -
Catch it if the initAsync() throws an error
The FutureBuilder will fail, but you can examine the error
inherited
-
onCheckerboardOffscreenLayers(
) → bool? -
Returns 'Off Screen Layers Checkerboard' boolean indicator if any.
inherited
-
onCheckerboardRasterCacheImages(
) → bool? -
Returns 'Raster Cache Checkerboard' boolean indicator if any.
inherited
-
onColor(
) → Color? -
Returns the App's Color if any.
inherited
-
onControllerError(
StateX< StatefulWidget> state, FlutterErrorDetails details) → void -
Step through its Controllers
inherited
-
onDarkTheme(
[BuildContext? context]) → ThemeData? -
Returns the App's 'Dark Theme' ThemeData if any.
inherited
-
onDebugEnhanceBuildTimelineArguments(
) → bool? -
Returns 'debugging information to 'Timeline' events' boolean indicator.
inherited
-
onDebugHighlightDeprecatedWidgets(
) → bool? -
Returns 'Show banners for deprecated widgets' boolean indicator.
inherited
-
onDebugOnRebuildDirtyWidget(
) → RebuildDirtyWidgetCallback? -
Returns 'Callback invoked for every dirty widget built' boolean indicator.
inherited
-
onDebugPaintBaselinesEnabled(
) → bool? -
Returns 'to paint a line at each of its baselines' boolean indicator.
inherited
-
onDebugPaintLayerBordersEnabled(
) → bool? -
Returns 'to paint a box around its bounds' boolean indicator.
inherited
-
onDebugPaintPointersEnabled(
) → bool? -
Returns 'to flash when tapped' boolean indicator.
inherited
-
onDebugPaintSizeEnabled(
) → bool? -
Returns 'Highlights UI while debugging' boolean indicator.
inherited
-
onDebugPrintBuildScope(
) → bool? -
Returns 'Highlights UI while debugging' boolean indicator.
inherited
-
onDebugPrintGlobalKeyedWidgetLifecycle(
) → bool? -
Returns 'when widgets with global keys are deactivate' boolean indicator.
inherited
-
onDebugPrintRebuildDirtyWidgets(
) → bool? -
Returns 'Log the dirty widgets that are built each frame' boolean indicator.
inherited
-
onDebugPrintScheduleBuildForStacks(
) → bool? -
Returns 'mark widgets needed to be rebuilt' boolean indicator.
inherited
-
onDebugProfileBuildsEnabled(
) → bool? -
Returns 'Adds 'Timeline' events' boolean indicator.
inherited
-
onDebugProfileBuildsEnabledUserWidgets(
) → bool? -
Returns 'Highlights UI while debugging' boolean indicator.
inherited
-
onDebugRepaintRainbowEnabled(
) → bool? -
Returns 'Overlay a rotating set of colors' boolean indicator.
inherited
-
onDebugRepaintTextRainbowEnabled(
) → bool? -
Returns 'Overlay a rotating set of colors' boolean indicator.
inherited
-
onDebugShowCheckedModeBanner(
) → bool? -
Returns 'Show Debug Banner' boolean indicator if any.
inherited
-
onDebugShowMaterialGrid(
) → bool? -
Returns 'Show Material Grid' boolean indicator if any.
inherited
-
onDebugShowWidgetInspector(
) → bool? -
Returns 'Show Debug Banner' boolean indicator if any.
inherited
-
onError(
FlutterErrorDetails details) → void -
Supply an 'error handler' routine to fire when an error occurs.
Override if you like to customize error handling.
inherited
-
onErrorHandler(
FlutterErrorDetails details) → void -
Override to provide an 'overall' Error Handler for your app.
Called in onError(FlutterErrorDetails details)
inherited
-
onErrorReport(
Object exception, StackTrace stack) → Future< void> -
If there's a error reporting routine available.
Override if you like
inherited
-
onErrorScreen(
FlutterErrorDetails details) → Widget? -
The Widget to display when an app's widget fails to display.
Override if you like.
inherited
-
onGenerateRoute(
RouteSettings settings) → Route? -
inherited
-
onHighContrastDarkTheme(
[BuildContext? context]) → ThemeData? -
Returns the App's 'High Contrast Dark Theme' ThemeData if any.
inherited
-
onHighContrastTheme(
[BuildContext? context]) → ThemeData? -
Returns the App's 'High Contrast Theme' ThemeData if any.
inherited
-
onHome(
) → Widget? -
Returns the home screen if any.
inherited
-
onInitAsync(
) → Future< bool> -
Used to complete asynchronous operations
inherited
-
onInitialRoute(
) → String? -
Returns the initial Route if any.
inherited
-
oniOSTheme(
[BuildContext? context]) → CupertinoThemeData? -
Returns the App's CupertinoThemeData if any.
inherited
-
onLocale(
) → Locale? -
Returns current Locale if any.
inherited
-
onLocaleListResolutionCallback(
List< Locale> ? locales, Iterable<Locale> supportedLocales) → Locale? -
Returns 'Locale Resolutions' routine if any.
inherited
-
onLocaleResolutionCallback(
Locale? locale, Iterable< Locale> supportedLocales) → Locale? -
Returns 'Local Resolution' routine if any.
Turn to the I10n class to provide the locale.
inherited
-
onLocalizationsDelegates(
) → Iterable< LocalizationsDelegate> ? -
Returns the 'Localization Delegates' if any.
inherited
-
Returns a List of Navigation Observers if any.
inherited
-
Called when a navigation event occurs
Return true if you deem this change is handled.
inherited
-
onRestorationScopeId(
) → String? -
Returns the 'Restore Scope Id' routine if any.
inherited
-
onRouteInformationParser(
) → RouteInformationParser< Object> ? -
Returns the Route Parser if any.
inherited
-
onRouteInformationProvider(
) → RouteInformationProvider? -
Returns the Route Provider if any.
inherited
-
onRouterConfig(
) → RouterConfig< Object> ? -
Returns the Route Config if any.
inherited
-
onRouterDelegate(
) → RouterDelegate< Object> ? -
Returns the Route Delegate if any.
inherited
-
onRoutes(
) → Map< String, WidgetBuilder> ? -
Returns a Map of Routes if any.
inherited
-
onScaffoldMessengerKey(
) → GlobalKey< ScaffoldMessengerState> ? -
Returns the App's ScaffoldMessenger Key.
inherited
-
onScrollBehavior(
) → ScrollBehavior? -
Returns the App's ScrollBehavior if any.
inherited
-
onShortcuts(
) → Map< LogicalKeySet, Intent> ? -
Returns Map of 'LogicalKeySets' if any.
inherited
-
onShowPerformanceOverlay(
) → bool? -
Returns 'Show Performance Overlay' boolean indicator if any.
inherited
-
onShowSemanticsDebugger(
) → bool? -
Returns 'Show Semantics' boolean indicator if any.
inherited
-
onSplashScreen(
BuildContext context) → Widget? -
Supply a 'splash screen' while the FutureBuilder is processing.
override
-
onStateError(
FlutterErrorDetails details) → bool -
Call the latest SateX object's error routine
Possibly the error occurred there.
inherited
-
onSupportedLocales(
) → List< Locale> ? -
Returns the Locale Iteration if any.
inherited
-
onSwitchUI(
) → bool? - Whether to switch from the 'default' interface
-
onTheme(
[BuildContext? context]) → ThemeData? -
Returns the App's ThemeData if any.
inherited
-
onThemeAnimationCurve(
) → Curve? -
Returns the App's ThemeMode if any.
inherited
-
onThemeAnimationDuration(
) → Duration? -
Returns the App's ThemeMode if any.
inherited
-
onThemeAnimationStyle(
) → AnimationStyle? -
Used to override the theme animation curve and duration.
inherited
-
onThemeMode(
) → ThemeMode? -
Returns the App's ThemeMode if any.
inherited
-
onTitle(
) → String -
Returns the App's title if any.
inherited
-
onUnknownRoute(
RouteSettings settings) → Route? -
Return the 'unknown' route
inherited
-
onUpdateShouldNotify(
covariant InheritedWidget oldWidget) → bool -
Should update the built-in InheritedWidget's dependencies
inherited
-
pausedAppLifecycleState(
) → void -
The application is not currently visible to the user, not responding to
user input, and running in the background.
inherited
-
reassemble(
) → void -
During development, if a hot reload occurs, the reassemble method is called.
This provides an opportunity to reinitialize any data that was prepared
in the initState method.
inherited
-
recordErrorInHandler(
[Object? error, StackTrace? stack]) → Object? -
inherited
-
recordException(
[Object? error, StackTrace? stack]) → Object? -
Return the 'last' error if any.
inherited
-
refresh(
) → void - Rebuild the 'latest/current' State object and the 'root/first' State object This is to address the possibility an App has called another App.
-
remove(
StateXController? con) → bool -
Remove a 'StateXController'
Returns boolean if successful.
inherited
-
removeByKey(
String? id) → bool -
Remove a specific 'StateXController' by its unique 'key' identifier.
inherited
-
Remove a Navigation listener.
inherited
-
resumedAppLifecycleState(
) → void -
The application is visible and responding to user input.
inherited
-
routeGenerator(
RouteSettings? settings, [Map< String, WidgetBuilder> ? routeMap]) → Route? -
Attempt to generate a Rout from the App's list of Route if any
inherited
-
runInitAsync(
) → bool -
Calls initAsync() all the time if returns true.
Conditional calls initAsync() creating a Future with every rebuild
inherited
-
setBuilder(
WidgetBuilder? builder) → Widget -
Called when the State's InheritedWidget is called again
This 'widget function' will be called again.
inherited
-
setiOSThemeData(
BuildContext context) → CupertinoThemeData? - Assigning the Cupertino theme
-
setState(
VoidCallback fn) → void -
Calls the State object's setState() function if not
(see class SetState).
inherited
-
setThemeData(
BuildContext context) → ThemeData? - Assigning the Material theme
-
stateById(
String? id) → StateX< StatefulWidget> ? -
Returns a State object using a unique String identifier.
inherited
-
stateByType<
T extends StateX< (StatefulWidget> >) → T? -
Retrieve the State object by type
Returns null if not found
inherited
-
statesById(
List< String> ids) → Map<String, StateX< StatefulWidget> > -
Returns a Map of StateView objects using unique String identifiers.
inherited
-
stateSet(
WidgetBuilder? builder) → Widget -
Called when the State's InheritedWidget is called again
This 'widget function' will be called again.
inherited
-
statesList(
{bool? reversed, StateX< StatefulWidget> ? remove}) → List<StateX< StatefulWidget> > -
Return a List of available StateX objects
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
updateShouldNotify(
covariant InheritedWidget oldWidget) → bool -
Determine if the dependencies should be updated.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- app → AppObjectImperium
-
Supply a final static instance of the AppObjectImperium object
final