hiddenAppLifecycle property

bool get hiddenAppLifecycle
inherited

All views of an application are hidden, either because the application is about to be paused (on iOS and Android), or because it has been minimized or placed on a desktop that is no longer visible (on non-web desktop), or is running in a window or tab that is no longer visible (on the web). State object was in a 'hidden' state

Implementation

// Save on function calls
// @override
// void hiddenAppLifecycleState() {
//   // Optionally call super for debugPrint()
//   super.hiddenAppLifecycleState();
// }

/// State object was in a 'hidden' state
bool get hiddenAppLifecycle => _hiddenAppLifecycle;