Imperium
A Framework for Flutter's Framework
Allows for faster and easier development with better maintainability. It looks like Flutter because it works like Flutter.
There's no 're-inventing of the wheel' here.
If you know Flutter, you'll know Imperium.
It supplies the adaptive functions and features expected of a production-ready app:
- An extended State class offering a built-in FutureBuilder or InheritedWidget.
- A State Object Controller class for this State class
- Extensive and essential error handling
- Easy implementation of both the Material & Cupertino interface for one app i.e. One app with both an Android and iOS interface.
- App-wide accessibility to your app's preferences using Shared Preferences
- 27 device event-handlers
- A loading screen option
Imperium Documentation
Libraries
- controller
- controller/app_statex_controller_imperium
- controller/error_handler_imperium
- controller/handle_error_imperium
- controller/platforms/run_app_imperium
- controller/platforms/run_webapp_imperium
- model
- view
- view/app/debug_paint_print_profile_options_mixin
- view/app/object/app_object_binding_mixin_imperium
- view/app/object/app_object_context_mixin_imperium
- view/app/object/app_object_statex_mixin_imperium
- view/app/object/app_object_theme_mixin_imperium
- view/app_object_imperium
- view/app_statex_imperium
- view/app_statexwidget_imperium
- view/run_app_imperium