deactivate method
void
deactivate()
The framework calls this method whenever it removes this StateX object
from the tree.
Implementation
void deactivate() {
/// The framework calls this method whenever it removes this [State] object
/// from the tree. It might reinsert it into another part of the tree.
/// Subclasses should override this method to clean up any links between
/// this object and other elements in the tree (e.g. if you have provided an
/// ancestor with a pointer to a descendant's [RenderObject]).
assert(() {
if (_debugPrintEvents) {
debugPrint('$_consoleLeadingLine deactivate() in $_consoleClassName');
}
return true;
}());
}