AsyncOps mixin StateX class State Object Controller
Supply the Async API to StateX and StateXController
initAsync, initAsyncState and onAsyncError
dartdoc:
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initAsyncCalled → bool
-
Flag indicating initAsync() has been called
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
initAsync(
) → Future< bool> - Initialize any 'time-consuming' operations at the beginning. Implement any asynchronous operations needed done at start up.
-
initAsyncState(
covariant State< StatefulWidget> state) → Future<bool> -
Called with every
StateXassociated with this Controller Initialize any 'time-consuming' operations at the beginning. Implement any asynchronous operations needed done at start up. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAsyncError(
FlutterErrorDetails details) → void - initAsync() has failed and a 'error' widget instead will be displayed. This takes in the snapshot.error details.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited