SetStateMixin mixin State Object Controller
Used by StateXController. Allows you to call setState function from the 'current' the State object.
dartdoc:
Properties
-
firstState
→ StateX<
StatefulWidget> ? -
Return the first State object
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- inDebugMode → bool
-
Determines if running in an IDE or in production.
Returns true if the App is under in the Debugger and not production.
no setter
- lastContext → BuildContext?
-
Returns the 'latest' context in the App.
no setter
-
lastState
→ StateX<
StatefulWidget> ? -
Return the 'latest' State object
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
↔ StateX<
StatefulWidget> ? -
Supply the State object
covariantgetter/setter pair
Methods
-
disposeSetState(
) → void - Clean up memory in case not empty
-
forEachState(
void func(StateX< StatefulWidget> state), {bool? reversed}) → bool -
To externally 'process' through the State objects.
Invokes
funcon each StateX possessed by this object. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
ofState<
T extends StateX< (StatefulWidget> >) → T? - Retrieve the StateX object of type T Returns null if not found
-
setState(
VoidCallback fn) → void - Calls the 'current' State object's setState() function if any.
-
stateOf<
T extends StatefulWidget> () → StateX< StatefulWidget> ? - Retrieve the State object by its StatefulWidget. Returns null if not found.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited