AppObjectContextMixinImperium class mixin
- Implementers
Constructors
Properties
- asSmallScreen → bool
-
Set whether the app is to use a 'small screen' or not.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- inAndroid → bool
-
no setter
- inFuchsia → bool
-
no setter
- iniOS → bool
-
no setter
- inLinux → bool
-
no setter
- inMobile → bool
-
no setter
- inSmallScreen → bool
-
Return the bool value indicating if running in a small screen or not.
no setter
- inWeb → bool
-
no setter
- inWindows → bool
-
no setter
- mainWindow → FlutterView
-
Flutter application's main window.
no setter
- platform → TargetPlatform?
-
The running platform
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaffold → ScaffoldState?
-
The Scaffold object for this App's View.
no setter
- screenHeight → double
-
The 'Logical' height of the screen
no setter
- screenPhysicalHeight → double
-
The Physical height of the screen
no setter
- screenPhysicalWidth → double
-
The Physical width of the screen
no setter
- screenSize → Size
-
Current Screen Size
no setter
- screenWidth → double
-
The 'logical' width of the screen
no setter
Methods
-
getPlatform(
BuildContext context) → TargetPlatform - Determine the running platform
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
snackBar(
{Key? key, Widget? content, String? message, Color? backgroundColor, double? elevation, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, double? width, ShapeBorder? shape, SnackBarBehavior? behavior, SnackBarAction? action, Duration? duration, Animation< double> ? animation, VoidCallback? onVisible, DismissDirection? dismissDirection, Clip? clipBehavior, int? durationMillis, int? animationDurationMillis}) → void - Display the SnackBar
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited