switchUI property
bool
get
switchUI
Allow the app to change the theme Allow the app directly change the Locale Allow the app to directly change the UI design Use Cupertino UI in Android and vice versa.
Implementation
// bool get allowChangeTheme => _allowChangeTheme;
// late bool _allowChangeTheme;
// todo: Fluttery
/// Allow the app directly change the Locale
// bool get allowChangeLocale => _allowChangeLocale;
// late bool _allowChangeLocale;
// todo: Fluttery
/// Allow the app to directly change the UI design
// bool get allowChangeUI => _allowChangeUI;
// late bool _allowChangeUI;
/// Use Cupertino UI in Android and vice versa.
bool get switchUI => _switchUI;